@@ -16,6 +16,14 @@ def put_s3_object(bucket, key, body, content_type: str = None, credential_overri
     client.put_object(**params)
 
 
+def get_s3_object(bucket, key, credential_override=None) -> bytes:
+    client = _get_client('s3', credential_override)
+    return client.get_object(
+        Bucket=bucket,
+        Key=key
+    ).get('Body').read()
+
+
 def _get_client(name, credential_override):
     if credential_override is None:
         return boto3.client(name)
